# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.dashboard.v1 import domain_dashboard_pb2 as spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2


class DomainDashboardStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.dashboard.v1.DomainDashboard/create',
                request_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.CreateDomainDashboardRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.dashboard.v1.DomainDashboard/update',
                request_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.UpdateDomainDashboardRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.dashboard.v1.DomainDashboard/delete',
                request_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.dashboard.v1.DomainDashboard/get',
                request_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.GetDomainDashboardRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.FromString,
                )
        self.delete_version = channel.unary_unary(
                '/spaceone.api.dashboard.v1.DomainDashboard/delete_version',
                request_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.revert_version = channel.unary_unary(
                '/spaceone.api.dashboard.v1.DomainDashboard/revert_version',
                request_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.FromString,
                )
        self.get_version = channel.unary_unary(
                '/spaceone.api.dashboard.v1.DomainDashboard/get_version',
                request_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.GetDomainDashboardVersionRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionInfo.FromString,
                )
        self.list_versions = channel.unary_unary(
                '/spaceone.api.dashboard.v1.DomainDashboard/list_versions',
                request_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionsInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.dashboard.v1.DomainDashboard/list',
                request_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.dashboard.v1.DomainDashboard/stat',
                request_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class DomainDashboardServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete_version(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def revert_version(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_version(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list_versions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DomainDashboardServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.CreateDomainDashboardRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.UpdateDomainDashboardRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.GetDomainDashboardRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.SerializeToString,
            ),
            'delete_version': grpc.unary_unary_rpc_method_handler(
                    servicer.delete_version,
                    request_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'revert_version': grpc.unary_unary_rpc_method_handler(
                    servicer.revert_version,
                    request_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.SerializeToString,
            ),
            'get_version': grpc.unary_unary_rpc_method_handler(
                    servicer.get_version,
                    request_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.GetDomainDashboardVersionRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionInfo.SerializeToString,
            ),
            'list_versions': grpc.unary_unary_rpc_method_handler(
                    servicer.list_versions,
                    request_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionsInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.dashboard.v1.DomainDashboard', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DomainDashboard(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.dashboard.v1.DomainDashboard/create',
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.CreateDomainDashboardRequest.SerializeToString,
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.dashboard.v1.DomainDashboard/update',
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.UpdateDomainDashboardRequest.SerializeToString,
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.dashboard.v1.DomainDashboard/delete',
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.dashboard.v1.DomainDashboard/get',
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.GetDomainDashboardRequest.SerializeToString,
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete_version(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.dashboard.v1.DomainDashboard/delete_version',
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def revert_version(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.dashboard.v1.DomainDashboard/revert_version',
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionRequest.SerializeToString,
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_version(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.dashboard.v1.DomainDashboard/get_version',
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.GetDomainDashboardVersionRequest.SerializeToString,
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list_versions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.dashboard.v1.DomainDashboard/list_versions',
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionQuery.SerializeToString,
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardVersionsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.dashboard.v1.DomainDashboard/list',
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardQuery.SerializeToString,
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.dashboard.v1.DomainDashboard/stat',
            spaceone_dot_api_dot_dashboard_dot_v1_dot_domain__dashboard__pb2.DomainDashboardStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/dashboard/v1/domain_dashboard.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0spaceone/api/dashboard/v1/domain_dashboard.proto\x12\x19spaceone.api.dashboard.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"+\n\x18\x44omainDashboardDateRange\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"*\n\x17\x44omainDashboardCurrency\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"\xa8\x01\n\x17\x44omainDashboardSettings\x12G\n\ndate_range\x18\x01 \x01(\x0b\x32\x33.spaceone.api.dashboard.v1.DomainDashboardDateRange\x12\x44\n\x08\x63urrency\x18\x02 \x01(\x0b\x32\x32.spaceone.api.dashboard.v1.DomainDashboardCurrency\"\xfc\x03\n\x1c\x43reateDomainDashboardRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12P\n\x07viewers\x18\x02 \x01(\x0e\x32?.spaceone.api.dashboard.v1.CreateDomainDashboardRequest.Viewers\x12+\n\x07layouts\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x32\n\x11\x64\x61shboard_options\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x44\n\x08settings\x18\x06 \x01(\x0b\x32\x32.spaceone.api.dashboard.v1.DomainDashboardSettings\x12\x39\n\x18\x64\x61shboard_options_schema\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\n \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"4\n\x07Viewers\x12\x10\n\x0cVIEWERS_NONE\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0b\n\x07PRIVATE\x10\x02\"\x91\x03\n\x1cUpdateDomainDashboardRequest\x12\x1b\n\x13\x64omain_dashboard_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12+\n\x07layouts\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x32\n\x11\x64\x61shboard_options\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x44\n\x08settings\x18\x06 \x01(\x0b\x32\x32.spaceone.api.dashboard.v1.DomainDashboardSettings\x12\x39\n\x18\x64\x61shboard_options_schema\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\n \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"H\n\x16\x44omainDashboardRequest\x12\x1b\n\x13\x64omain_dashboard_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"Y\n\x19GetDomainDashboardRequest\x12\x1b\n\x13\x64omain_dashboard_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"`\n\x1d\x44omainDashboardVersionRequest\x12\x1b\n\x13\x64omain_dashboard_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\x05\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"q\n GetDomainDashboardVersionRequest\x12\x1b\n\x13\x64omain_dashboard_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x11\n\tdomain_id\x18\n \x01(\t\x12\x0c\n\x04only\x18\x0b \x03(\t\"\x8a\x01\n\x1b\x44omainDashboardVersionQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x1b\n\x13\x64omain_dashboard_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x11\n\tdomain_id\x18\n \x01(\t\"\x91\x02\n\x14\x44omainDashboardQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x1b\n\x13\x64omain_dashboard_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12H\n\x07viewers\x18\x04 \x01(\x0e\x32\x37.spaceone.api.dashboard.v1.DomainDashboardQuery.Viewers\x12\x0f\n\x07user_id\x18\n \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"4\n\x07Viewers\x12\x10\n\x0cVIEWERS_NONE\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0b\n\x07PRIVATE\x10\x02\"\xd1\x04\n\x13\x44omainDashboardInfo\x12\x1b\n\x13\x64omain_dashboard_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12G\n\x07viewers\x18\x03 \x01(\x0e\x32\x36.spaceone.api.dashboard.v1.DomainDashboardInfo.Viewers\x12\x0f\n\x07version\x18\x04 \x01(\x05\x12+\n\x07layouts\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x32\n\x11\x64\x61shboard_options\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x44\n\x08settings\x18\x07 \x01(\x0b\x32\x32.spaceone.api.dashboard.v1.DomainDashboardSettings\x12\x39\n\x18\x64\x61shboard_options_schema\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\n \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07user_id\x18\x14 \x01(\t\x12\x11\n\tdomain_id\x18\x15 \x01(\t\x12\x12\n\ncreated_at\x18\x16 \x01(\t\x12\x12\n\nupdated_at\x18\x17 \x01(\t\"4\n\x07Viewers\x12\x10\n\x0cVIEWERS_NONE\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0b\n\x07PRIVATE\x10\x02\"l\n\x14\x44omainDashboardsInfo\x12?\n\x07results\x18\x01 \x03(\x0b\x32..spaceone.api.dashboard.v1.DomainDashboardInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"c\n\x18\x44omainDashboardStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\xe3\x02\n\x1a\x44omainDashboardVersionInfo\x12\x1b\n\x13\x64omain_dashboard_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x0e\n\x06latest\x18\x03 \x01(\x08\x12+\n\x07layouts\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x32\n\x11\x64\x61shboard_options\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x44\n\x08settings\x18\x07 \x01(\x0b\x32\x32.spaceone.api.dashboard.v1.DomainDashboardSettings\x12\x39\n\x18\x64\x61shboard_options_schema\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x15 \x01(\t\x12\x12\n\ncreated_at\x18\x16 \x01(\t\"z\n\x1b\x44omainDashboardVersionsInfo\x12\x46\n\x07results\x18\x01 \x03(\x0b\x32\x35.spaceone.api.dashboard.v1.DomainDashboardVersionInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\xd3\x0e\n\x0f\x44omainDashboard\x12\x9a\x01\n\x06\x63reate\x12\x37.spaceone.api.dashboard.v1.CreateDomainDashboardRequest\x1a..spaceone.api.dashboard.v1.DomainDashboardInfo\"\'\x82\xd3\xe4\x93\x02!\"\x1f/dashboard/v1/domain-dashboards\x12\xaf\x01\n\x06update\x12\x37.spaceone.api.dashboard.v1.UpdateDomainDashboardRequest\x1a..spaceone.api.dashboard.v1.DomainDashboardInfo\"<\x82\xd3\xe4\x93\x02\x36\x1a\x34/dashboard/v1/domain-dashboard/{domain_dashboard_id}\x12\x91\x01\n\x06\x64\x65lete\x12\x31.spaceone.api.dashboard.v1.DomainDashboardRequest\x1a\x16.google.protobuf.Empty\"<\x82\xd3\xe4\x93\x02\x36*4/dashboard/v1/domain-dashboard/{domain_dashboard_id}\x12\xa9\x01\n\x03get\x12\x34.spaceone.api.dashboard.v1.GetDomainDashboardRequest\x1a..spaceone.api.dashboard.v1.DomainDashboardInfo\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/dashboard/v1/domain-dashboard/{domain_dashboard_id}\x12\xb2\x01\n\x0e\x64\x65lete_version\x12\x38.spaceone.api.dashboard.v1.DomainDashboardVersionRequest\x1a\x16.google.protobuf.Empty\"N\x82\xd3\xe4\x93\x02H*F/dashboard/v1/domain-dashboard/{domain_dashboard_id}/version/{version}\x12\xd1\x01\n\x0erevert_version\x12\x38.spaceone.api.dashboard.v1.DomainDashboardVersionRequest\x1a..spaceone.api.dashboard.v1.DomainDashboardInfo\"U\x82\xd3\xe4\x93\x02O\"M/dashboard/v1/domain-dashboard/{domain_dashboard_id}/version/{version}/revert\x12\xd1\x01\n\x0bget_version\x12;.spaceone.api.dashboard.v1.GetDomainDashboardVersionRequest\x1a\x35.spaceone.api.dashboard.v1.DomainDashboardVersionInfo\"N\x82\xd3\xe4\x93\x02H\x12\x46/dashboard/v1/domain-dashboard/{domain_dashboard_id}/version/{version}\x12\x90\x02\n\rlist_versions\x12\x36.spaceone.api.dashboard.v1.DomainDashboardVersionQuery\x1a\x36.spaceone.api.dashboard.v1.DomainDashboardVersionsInfo\"\x8e\x01\x82\xd3\xe4\x93\x02\x87\x01\x12=/dashboard/v1/domain-dashboard/{domain_dashboard_id}/versionsZF\"D/dashboard/v1/domain-dashboard/{domain_dashboard_id}/versions/search\x12\xbb\x01\n\x04list\x12/.spaceone.api.dashboard.v1.DomainDashboardQuery\x1a/.spaceone.api.dashboard.v1.DomainDashboardsInfo\"Q\x82\xd3\xe4\x93\x02K\x12\x1f/dashboard/v1/domain-dashboardsZ(\"&/dashboard/v1/domain-dashboards/search\x12\x82\x01\n\x04stat\x12\x33.spaceone.api.dashboard.v1.DomainDashboardStatQuery\x1a\x17.google.protobuf.Struct\",\x82\xd3\xe4\x93\x02&\"$/dashboard/v1/domain-dashboards/statb\x06proto3')



_DOMAINDASHBOARDDATERANGE = DESCRIPTOR.message_types_by_name['DomainDashboardDateRange']
_DOMAINDASHBOARDCURRENCY = DESCRIPTOR.message_types_by_name['DomainDashboardCurrency']
_DOMAINDASHBOARDSETTINGS = DESCRIPTOR.message_types_by_name['DomainDashboardSettings']
_CREATEDOMAINDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['CreateDomainDashboardRequest']
_UPDATEDOMAINDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['UpdateDomainDashboardRequest']
_DOMAINDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['DomainDashboardRequest']
_GETDOMAINDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['GetDomainDashboardRequest']
_DOMAINDASHBOARDVERSIONREQUEST = DESCRIPTOR.message_types_by_name['DomainDashboardVersionRequest']
_GETDOMAINDASHBOARDVERSIONREQUEST = DESCRIPTOR.message_types_by_name['GetDomainDashboardVersionRequest']
_DOMAINDASHBOARDVERSIONQUERY = DESCRIPTOR.message_types_by_name['DomainDashboardVersionQuery']
_DOMAINDASHBOARDQUERY = DESCRIPTOR.message_types_by_name['DomainDashboardQuery']
_DOMAINDASHBOARDINFO = DESCRIPTOR.message_types_by_name['DomainDashboardInfo']
_DOMAINDASHBOARDSINFO = DESCRIPTOR.message_types_by_name['DomainDashboardsInfo']
_DOMAINDASHBOARDSTATQUERY = DESCRIPTOR.message_types_by_name['DomainDashboardStatQuery']
_DOMAINDASHBOARDVERSIONINFO = DESCRIPTOR.message_types_by_name['DomainDashboardVersionInfo']
_DOMAINDASHBOARDVERSIONSINFO = DESCRIPTOR.message_types_by_name['DomainDashboardVersionsInfo']
_CREATEDOMAINDASHBOARDREQUEST_VIEWERS = _CREATEDOMAINDASHBOARDREQUEST.enum_types_by_name['Viewers']
_DOMAINDASHBOARDQUERY_VIEWERS = _DOMAINDASHBOARDQUERY.enum_types_by_name['Viewers']
_DOMAINDASHBOARDINFO_VIEWERS = _DOMAINDASHBOARDINFO.enum_types_by_name['Viewers']
DomainDashboardDateRange = _reflection.GeneratedProtocolMessageType('DomainDashboardDateRange', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINDASHBOARDDATERANGE,
  '__module__' : 'spaceone.api.dashboard.v1.domain_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.DomainDashboardDateRange)
  })
_sym_db.RegisterMessage(DomainDashboardDateRange)

DomainDashboardCurrency = _reflection.GeneratedProtocolMessageType('DomainDashboardCurrency', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINDASHBOARDCURRENCY,
  '__module__' : 'spaceone.api.dashboard.v1.domain_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.DomainDashboardCurrency)
  })
_sym_db.RegisterMessage(DomainDashboardCurrency)

DomainDashboardSettings = _reflection.GeneratedProtocolMessageType('DomainDashboardSettings', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINDASHBOARDSETTINGS,
  '__module__' : 'spaceone.api.dashboard.v1.domain_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.DomainDashboardSettings)
  })
_sym_db.RegisterMessage(DomainDashboardSettings)

CreateDomainDashboardRequest = _reflection.GeneratedProtocolMessageType('CreateDomainDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDOMAINDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.dashboard.v1.domain_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.CreateDomainDashboardRequest)
  })
_sym_db.RegisterMessage(CreateDomainDashboardRequest)

UpdateDomainDashboardRequest = _reflection.GeneratedProtocolMessageType('UpdateDomainDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDOMAINDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.dashboard.v1.domain_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.UpdateDomainDashboardRequest)
  })
_sym_db.RegisterMessage(UpdateDomainDashboardRequest)

DomainDashboardRequest = _reflection.GeneratedProtocolMessageType('DomainDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.dashboard.v1.domain_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.DomainDashboardRequest)
  })
_sym_db.RegisterMessage(DomainDashboardRequest)

GetDomainDashboardRequest = _reflection.GeneratedProtocolMessageType('GetDomainDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDOMAINDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.dashboard.v1.domain_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.GetDomainDashboardRequest)
  })
_sym_db.RegisterMessage(GetDomainDashboardRequest)

DomainDashboardVersionRequest = _reflection.GeneratedProtocolMessageType('DomainDashboardVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINDASHBOARDVERSIONREQUEST,
  '__module__' : 'spaceone.api.dashboard.v1.domain_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.DomainDashboardVersionRequest)
  })
_sym_db.RegisterMessage(DomainDashboardVersionRequest)

GetDomainDashboardVersionRequest = _reflection.GeneratedProtocolMessageType('GetDomainDashboardVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDOMAINDASHBOARDVERSIONREQUEST,
  '__module__' : 'spaceone.api.dashboard.v1.domain_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.GetDomainDashboardVersionRequest)
  })
_sym_db.RegisterMessage(GetDomainDashboardVersionRequest)

DomainDashboardVersionQuery = _reflection.GeneratedProtocolMessageType('DomainDashboardVersionQuery', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINDASHBOARDVERSIONQUERY,
  '__module__' : 'spaceone.api.dashboard.v1.domain_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.DomainDashboardVersionQuery)
  })
_sym_db.RegisterMessage(DomainDashboardVersionQuery)

DomainDashboardQuery = _reflection.GeneratedProtocolMessageType('DomainDashboardQuery', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINDASHBOARDQUERY,
  '__module__' : 'spaceone.api.dashboard.v1.domain_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.DomainDashboardQuery)
  })
_sym_db.RegisterMessage(DomainDashboardQuery)

DomainDashboardInfo = _reflection.GeneratedProtocolMessageType('DomainDashboardInfo', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINDASHBOARDINFO,
  '__module__' : 'spaceone.api.dashboard.v1.domain_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.DomainDashboardInfo)
  })
_sym_db.RegisterMessage(DomainDashboardInfo)

DomainDashboardsInfo = _reflection.GeneratedProtocolMessageType('DomainDashboardsInfo', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINDASHBOARDSINFO,
  '__module__' : 'spaceone.api.dashboard.v1.domain_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.DomainDashboardsInfo)
  })
_sym_db.RegisterMessage(DomainDashboardsInfo)

DomainDashboardStatQuery = _reflection.GeneratedProtocolMessageType('DomainDashboardStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINDASHBOARDSTATQUERY,
  '__module__' : 'spaceone.api.dashboard.v1.domain_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.DomainDashboardStatQuery)
  })
_sym_db.RegisterMessage(DomainDashboardStatQuery)

DomainDashboardVersionInfo = _reflection.GeneratedProtocolMessageType('DomainDashboardVersionInfo', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINDASHBOARDVERSIONINFO,
  '__module__' : 'spaceone.api.dashboard.v1.domain_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.DomainDashboardVersionInfo)
  })
_sym_db.RegisterMessage(DomainDashboardVersionInfo)

DomainDashboardVersionsInfo = _reflection.GeneratedProtocolMessageType('DomainDashboardVersionsInfo', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINDASHBOARDVERSIONSINFO,
  '__module__' : 'spaceone.api.dashboard.v1.domain_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.DomainDashboardVersionsInfo)
  })
_sym_db.RegisterMessage(DomainDashboardVersionsInfo)

_DOMAINDASHBOARD = DESCRIPTOR.services_by_name['DomainDashboard']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DOMAINDASHBOARD.methods_by_name['create']._options = None
  _DOMAINDASHBOARD.methods_by_name['create']._serialized_options = b'\202\323\344\223\002!\"\037/dashboard/v1/domain-dashboards'
  _DOMAINDASHBOARD.methods_by_name['update']._options = None
  _DOMAINDASHBOARD.methods_by_name['update']._serialized_options = b'\202\323\344\223\0026\0324/dashboard/v1/domain-dashboard/{domain_dashboard_id}'
  _DOMAINDASHBOARD.methods_by_name['delete']._options = None
  _DOMAINDASHBOARD.methods_by_name['delete']._serialized_options = b'\202\323\344\223\0026*4/dashboard/v1/domain-dashboard/{domain_dashboard_id}'
  _DOMAINDASHBOARD.methods_by_name['get']._options = None
  _DOMAINDASHBOARD.methods_by_name['get']._serialized_options = b'\202\323\344\223\0026\0224/dashboard/v1/domain-dashboard/{domain_dashboard_id}'
  _DOMAINDASHBOARD.methods_by_name['delete_version']._options = None
  _DOMAINDASHBOARD.methods_by_name['delete_version']._serialized_options = b'\202\323\344\223\002H*F/dashboard/v1/domain-dashboard/{domain_dashboard_id}/version/{version}'
  _DOMAINDASHBOARD.methods_by_name['revert_version']._options = None
  _DOMAINDASHBOARD.methods_by_name['revert_version']._serialized_options = b'\202\323\344\223\002O\"M/dashboard/v1/domain-dashboard/{domain_dashboard_id}/version/{version}/revert'
  _DOMAINDASHBOARD.methods_by_name['get_version']._options = None
  _DOMAINDASHBOARD.methods_by_name['get_version']._serialized_options = b'\202\323\344\223\002H\022F/dashboard/v1/domain-dashboard/{domain_dashboard_id}/version/{version}'
  _DOMAINDASHBOARD.methods_by_name['list_versions']._options = None
  _DOMAINDASHBOARD.methods_by_name['list_versions']._serialized_options = b'\202\323\344\223\002\207\001\022=/dashboard/v1/domain-dashboard/{domain_dashboard_id}/versionsZF\"D/dashboard/v1/domain-dashboard/{domain_dashboard_id}/versions/search'
  _DOMAINDASHBOARD.methods_by_name['list']._options = None
  _DOMAINDASHBOARD.methods_by_name['list']._serialized_options = b'\202\323\344\223\002K\022\037/dashboard/v1/domain-dashboardsZ(\"&/dashboard/v1/domain-dashboards/search'
  _DOMAINDASHBOARD.methods_by_name['stat']._options = None
  _DOMAINDASHBOARD.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002&\"$/dashboard/v1/domain-dashboards/stat'
  _DOMAINDASHBOARDDATERANGE._serialized_start=202
  _DOMAINDASHBOARDDATERANGE._serialized_end=245
  _DOMAINDASHBOARDCURRENCY._serialized_start=247
  _DOMAINDASHBOARDCURRENCY._serialized_end=289
  _DOMAINDASHBOARDSETTINGS._serialized_start=292
  _DOMAINDASHBOARDSETTINGS._serialized_end=460
  _CREATEDOMAINDASHBOARDREQUEST._serialized_start=463
  _CREATEDOMAINDASHBOARDREQUEST._serialized_end=971
  _CREATEDOMAINDASHBOARDREQUEST_VIEWERS._serialized_start=919
  _CREATEDOMAINDASHBOARDREQUEST_VIEWERS._serialized_end=971
  _UPDATEDOMAINDASHBOARDREQUEST._serialized_start=974
  _UPDATEDOMAINDASHBOARDREQUEST._serialized_end=1375
  _DOMAINDASHBOARDREQUEST._serialized_start=1377
  _DOMAINDASHBOARDREQUEST._serialized_end=1449
  _GETDOMAINDASHBOARDREQUEST._serialized_start=1451
  _GETDOMAINDASHBOARDREQUEST._serialized_end=1540
  _DOMAINDASHBOARDVERSIONREQUEST._serialized_start=1542
  _DOMAINDASHBOARDVERSIONREQUEST._serialized_end=1638
  _GETDOMAINDASHBOARDVERSIONREQUEST._serialized_start=1640
  _GETDOMAINDASHBOARDVERSIONREQUEST._serialized_end=1753
  _DOMAINDASHBOARDVERSIONQUERY._serialized_start=1756
  _DOMAINDASHBOARDVERSIONQUERY._serialized_end=1894
  _DOMAINDASHBOARDQUERY._serialized_start=1897
  _DOMAINDASHBOARDQUERY._serialized_end=2170
  _DOMAINDASHBOARDQUERY_VIEWERS._serialized_start=919
  _DOMAINDASHBOARDQUERY_VIEWERS._serialized_end=971
  _DOMAINDASHBOARDINFO._serialized_start=2173
  _DOMAINDASHBOARDINFO._serialized_end=2766
  _DOMAINDASHBOARDINFO_VIEWERS._serialized_start=919
  _DOMAINDASHBOARDINFO_VIEWERS._serialized_end=971
  _DOMAINDASHBOARDSINFO._serialized_start=2768
  _DOMAINDASHBOARDSINFO._serialized_end=2876
  _DOMAINDASHBOARDSTATQUERY._serialized_start=2878
  _DOMAINDASHBOARDSTATQUERY._serialized_end=2977
  _DOMAINDASHBOARDVERSIONINFO._serialized_start=2980
  _DOMAINDASHBOARDVERSIONINFO._serialized_end=3335
  _DOMAINDASHBOARDVERSIONSINFO._serialized_start=3337
  _DOMAINDASHBOARDVERSIONSINFO._serialized_end=3459
  _DOMAINDASHBOARD._serialized_start=3462
  _DOMAINDASHBOARD._serialized_end=5337
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc



class ConsumersStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """


class ConsumersServicer(object):
    """Missing associated documentation comment in .proto file."""


def add_ConsumersServicer_to_server(servicer, server):
    rpc_method_handlers = {
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.provisioning.v1.Consumers', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Consumers(object):
    """Missing associated documentation comment in .proto file."""



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.notification.v1 import user_channel_pb2 as spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2


class UserChannelStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.notification.v1.UserChannel/create',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.CreateUserChannelRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.notification.v1.UserChannel/update',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UpdateUserChannelRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelInfo.FromString,
                )
        self.set_schedule = channel.unary_unary(
                '/spaceone.api.notification.v1.UserChannel/set_schedule',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UpdateUserChannelScheduleRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelInfo.FromString,
                )
        self.set_subscription = channel.unary_unary(
                '/spaceone.api.notification.v1.UserChannel/set_subscription',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UpdateUserChannelSubscriptionRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelInfo.FromString,
                )
        self.enable = channel.unary_unary(
                '/spaceone.api.notification.v1.UserChannel/enable',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelInfo.FromString,
                )
        self.disable = channel.unary_unary(
                '/spaceone.api.notification.v1.UserChannel/disable',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.notification.v1.UserChannel/delete',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.notification.v1.UserChannel/get',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.GetUserChannelRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.notification.v1.UserChannel/list',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.notification.v1.UserChannel/stat',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class UserChannelServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new UserChannel. A UserChannel is a channel that delivers a Notification to users when the Notification is created. When creating a UserChannel, one Protocol must be selected, and an Notification is dispatched via the selected Protocol.
        request_example: >-
        {
        "protocol_id": "protocol-123456789012",
        "name": "Email",
        "data": {
        "email": "user1@email.com"
        },
        "user_id": "user1@email.com",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "user_channel_id": "user-ch-123456789012",
        "name": "Email",
        "state": "ENABLED",
        "data": {
        "email": "user1@email.com"
        },
        "protocol_id": "protocol-123456789012",
        "user_id": "user1@email.com",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T08:28:49.108Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific UserChannel. A UserChannel that has already been configured cannot be changed. Instead, the data required for dispatching Notifications to a UserChannel can be updated.
        request_example: >-
        {
        "user_channel_id": "user-ch-123456789012",
        "name": "Email2",
        "data": {
        "email": "user1@gmail.com"
        },
        "tags": {
        "type": "test"
        }
        }
        response_example: >-
        {
        "user_channel_id": "user-ch-123456789012",
        "name": "Email2",
        "state": "ENABLED",
        "data": {
        "email": "user1@gmail.com"
        },
        "protocol_id": "protocol-123456789012",
        "user_id": "user1@email.com",
        "tags": {
        "type": "test"
        },
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T08:28:49.108Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def set_schedule(self, request, context):
        """
        desc: Sets a schedule for a UserChannel. A schedule defines the time to receive a Notification. When a Notification is created, you can set the day of the week and time you want to receive it. When you set the day of the week, you can receive a notification only on the day of the week you set. If you also set the start time and end time with the day of the week, you can receive a Notification only at the scheduled time on the day of the week you set. If there is no schedule set in a UserChannel, Notifications will be dispatched at all times via the UserChannel.
        request_example: >-
        {
        "user_channel_id": "user-ch-28097e8d5d59",
        "is_scheduled": true,
        "schedule": {
        "day_of_week": [
        "MON",
        "TUE",
        "WED",
        "THU",
        "FRI"
        ],
        "end_hour": 9
        },
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "user_channel_id": "user-ch-28097e8d5d59",
        "name": "my-email",
        "state": "ENABLED",
        "data": {
        "email": "seolmin@mz.co.kr"
        },
        "is_scheduled": true,
        "schedule": {
        "day_of_week": [
        "MON",
        "TUE",
        "WED",
        "THU",
        "FRI"
        ],
        "end_hour": 9
        },
        "protocol_id": "protocol-e000a677ebdb",
        "user_id": "user1@cloudforet.io",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-03T08:28:49.108Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def set_subscription(self, request, context):
        """
        desc: Sets a subscription for a UserChannel. A subscription is a topic for channels to subscribe to and get notified about. If a UserChannel has subscriptions, a Notification is dispatched only if the topic of the Notification is the same as the one set in the subscriptions. If there is no subscription in a UserChannel, all Notifications will be dispatched.
        request_example: >-
        {
        "user_channel_id": "user-ch-28097e8d5d59",
        "is_subscribe": true,
        "subscriptions": [
        "monitoring.Alert"
        ],
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "user_channel_id": "user-ch-28097e8d5d59",
        "name": "my-email",
        "state": "ENABLED",
        "data": {
        "email": "user1@cloudforet.io"
        },
        "is_subscribe": true,
        "subscriptions": [
        "monitoring.Alert"
        ],
        "is_scheduled": true,
        "schedule": {
        "day_of_week": [
        "MON",
        "TUE",
        "WED",
        "THU",
        "FRI"
        ],
        "end_hour": 9
        },
        "protocol_id": "protocol-e000a677ebdb",
        "user_id": "user1@cloudforet.io",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-03T08:28:49.108Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def enable(self, request, context):
        """
        desc: Enables a specific UserChannel. If a UserChannel is enabled, the UserChannel can be used and the Notification can be dispatched. Even if a UserChannel is enabled, if the Protocol used in the UserChannel is disabled, the Notification is not dispatched.
        request_example: >-
        {
        "user_channel_id": "user-ch-123456789012"
        }
        response_example: >-
        {
        "user_channel_id": "user-ch-123456789012",
        "name": "Email",
        "state": "ENABLED",
        "data": {
        "email": "user1@email.com"
        },
        "protocol_id": "protocol-123456789012",
        "user_id": "user1@email.com",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T08:28:49.108Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def disable(self, request, context):
        """
        desc: Disables a specific UserChannel. If a UserChannel is disabled, the Notification is not dispatched, even if it is created.
        request_example: >-
        {
        "user_channel_id": "user-ch-123456789012"
        }
        response_example: >-
        {
        "user_channel_id": "user-ch-123456789012",
        "name": "Email",
        "state": "DISABLED",
        "data": {
        "email": "user1@email.com"
        },
        "protocol_id": "protocol-123456789012",
        "user_id": "user1@email.com",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T08:28:49.108Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific UserChannel. You must specify the `user_channel_id` of the UserChannel to delete.
        request_example: >-
        {
        "user_channel_id": "user-ch-123456789012"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific UserChannel. Prints detailed information about the UserChannel, including the Protocol configured and the Notification settings.
        request_example: >-
        {
        "user_channel_id": "user-ch-123456789012"
        }
        response_example: >-
        {
        "user_channel_id": "user-ch-123456789012",
        "name": "Email",
        "state": "ENABLED",
        "data": {
        "email": "user1@email.com"
        },
        "protocol_id": "protocol-123456789012",
        "user_id": "user1@email.com",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T08:28:49.108Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all UserChannels. You can use a query to get a filtered list of UserChannels.
        request_example: >-
        {
        "query": {}
        }
        response_example: >-
        {
        "results": [
        {
        "user_channel_id": "user-ch-123456789012",
        "name": "Email",
        "state": "ENABLED",
        "data": {
        "email": "user1@email.com"
        },
        "protocol_id": "protocol-123456789012",
        "user_id": "user1@email.com",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T08:28:49.108Z"
        },
        {
        "user_channel_id": "user-ch-98765432109",
        "name": "Email",
        "state": "ENABLED",
        "data": {
        "email": "user2@email.com"
        },
        "is_scheduled": true,
        "schedule": {
        "day_of_week": [
        "MON",
        "TUE",
        "WED",
        "THU",
        "FRI"
        ],
        "start_hour": 3,
        "end_hour": 23
        },
        "protocol_id": "protocol-123456789012",
        "user_id": "user2@email.com",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T06:45:57.260Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserChannelServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.CreateUserChannelRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UpdateUserChannelRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelInfo.SerializeToString,
            ),
            'set_schedule': grpc.unary_unary_rpc_method_handler(
                    servicer.set_schedule,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UpdateUserChannelScheduleRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelInfo.SerializeToString,
            ),
            'set_subscription': grpc.unary_unary_rpc_method_handler(
                    servicer.set_subscription,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UpdateUserChannelSubscriptionRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelInfo.SerializeToString,
            ),
            'enable': grpc.unary_unary_rpc_method_handler(
                    servicer.enable,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelInfo.SerializeToString,
            ),
            'disable': grpc.unary_unary_rpc_method_handler(
                    servicer.disable,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.GetUserChannelRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.notification.v1.UserChannel', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UserChannel(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.UserChannel/create',
            spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.CreateUserChannelRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.UserChannel/update',
            spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UpdateUserChannelRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def set_schedule(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.UserChannel/set_schedule',
            spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UpdateUserChannelScheduleRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def set_subscription(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.UserChannel/set_subscription',
            spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UpdateUserChannelSubscriptionRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def enable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.UserChannel/enable',
            spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def disable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.UserChannel/disable',
            spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.UserChannel/delete',
            spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.UserChannel/get',
            spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.GetUserChannelRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.UserChannel/list',
            spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelQuery.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.UserChannel/stat',
            spaceone_dot_api_dot_notification_dot_v1_dot_user__channel__pb2.UserChannelStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/config/v1/user_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(spaceone/api/config/v1/user_config.proto\x12\x16spaceone.api.config.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\x85\x01\n\x14SetUserConfigRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"4\n\x11UserConfigRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"E\n\x14GetUserConfigRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"o\n\x0fUserConfigQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"\xb8\x01\n\x0eUserConfigInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07user_id\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x05 \x01(\t\x12\x12\n\ncreated_at\x18\x06 \x01(\t\x12\x12\n\nupdated_at\x18\x07 \x01(\t\"_\n\x0fUserConfigsInfo\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.spaceone.api.config.v1.UserConfigInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"^\n\x13UserConfigStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xa5\x07\n\nUserConfig\x12\x7f\n\x06\x63reate\x12,.spaceone.api.config.v1.SetUserConfigRequest\x1a&.spaceone.api.config.v1.UserConfigInfo\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x17/config/v1/user-configs\x12\x85\x01\n\x06update\x12,.spaceone.api.config.v1.SetUserConfigRequest\x1a&.spaceone.api.config.v1.UserConfigInfo\"%\x82\xd3\xe4\x93\x02\x1f\x1a\x1d/config/v1/user-config/{name}\x12\x82\x01\n\x03set\x12,.spaceone.api.config.v1.SetUserConfigRequest\x1a&.spaceone.api.config.v1.UserConfigInfo\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/config/v1/user-config/{name}\x12r\n\x06\x64\x65lete\x12).spaceone.api.config.v1.UserConfigRequest\x1a\x16.google.protobuf.Empty\"%\x82\xd3\xe4\x93\x02\x1f*\x1d/config/v1/user-config/{name}\x12\x82\x01\n\x03get\x12,.spaceone.api.config.v1.GetUserConfigRequest\x1a&.spaceone.api.config.v1.UserConfigInfo\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/config/v1/user-config/{name}\x12\x9b\x01\n\x04list\x12\'.spaceone.api.config.v1.UserConfigQuery\x1a\'.spaceone.api.config.v1.UserConfigsInfo\"A\x82\xd3\xe4\x93\x02;\x12\x17/config/v1/user-configsZ \"\x1e/config/v1/user-configs/search\x12r\n\x04stat\x12+.spaceone.api.config.v1.UserConfigStatQuery\x1a\x17.google.protobuf.Struct\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/config/v1/user-configs/statb\x06proto3')



_SETUSERCONFIGREQUEST = DESCRIPTOR.message_types_by_name['SetUserConfigRequest']
_USERCONFIGREQUEST = DESCRIPTOR.message_types_by_name['UserConfigRequest']
_GETUSERCONFIGREQUEST = DESCRIPTOR.message_types_by_name['GetUserConfigRequest']
_USERCONFIGQUERY = DESCRIPTOR.message_types_by_name['UserConfigQuery']
_USERCONFIGINFO = DESCRIPTOR.message_types_by_name['UserConfigInfo']
_USERCONFIGSINFO = DESCRIPTOR.message_types_by_name['UserConfigsInfo']
_USERCONFIGSTATQUERY = DESCRIPTOR.message_types_by_name['UserConfigStatQuery']
SetUserConfigRequest = _reflection.GeneratedProtocolMessageType('SetUserConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETUSERCONFIGREQUEST,
  '__module__' : 'spaceone.api.config.v1.user_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.config.v1.SetUserConfigRequest)
  })
_sym_db.RegisterMessage(SetUserConfigRequest)

UserConfigRequest = _reflection.GeneratedProtocolMessageType('UserConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _USERCONFIGREQUEST,
  '__module__' : 'spaceone.api.config.v1.user_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.config.v1.UserConfigRequest)
  })
_sym_db.RegisterMessage(UserConfigRequest)

GetUserConfigRequest = _reflection.GeneratedProtocolMessageType('GetUserConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERCONFIGREQUEST,
  '__module__' : 'spaceone.api.config.v1.user_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.config.v1.GetUserConfigRequest)
  })
_sym_db.RegisterMessage(GetUserConfigRequest)

UserConfigQuery = _reflection.GeneratedProtocolMessageType('UserConfigQuery', (_message.Message,), {
  'DESCRIPTOR' : _USERCONFIGQUERY,
  '__module__' : 'spaceone.api.config.v1.user_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.config.v1.UserConfigQuery)
  })
_sym_db.RegisterMessage(UserConfigQuery)

UserConfigInfo = _reflection.GeneratedProtocolMessageType('UserConfigInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERCONFIGINFO,
  '__module__' : 'spaceone.api.config.v1.user_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.config.v1.UserConfigInfo)
  })
_sym_db.RegisterMessage(UserConfigInfo)

UserConfigsInfo = _reflection.GeneratedProtocolMessageType('UserConfigsInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERCONFIGSINFO,
  '__module__' : 'spaceone.api.config.v1.user_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.config.v1.UserConfigsInfo)
  })
_sym_db.RegisterMessage(UserConfigsInfo)

UserConfigStatQuery = _reflection.GeneratedProtocolMessageType('UserConfigStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _USERCONFIGSTATQUERY,
  '__module__' : 'spaceone.api.config.v1.user_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.config.v1.UserConfigStatQuery)
  })
_sym_db.RegisterMessage(UserConfigStatQuery)

_USERCONFIG = DESCRIPTOR.services_by_name['UserConfig']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _USERCONFIG.methods_by_name['create']._options = None
  _USERCONFIG.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\031\"\027/config/v1/user-configs'
  _USERCONFIG.methods_by_name['update']._options = None
  _USERCONFIG.methods_by_name['update']._serialized_options = b'\202\323\344\223\002\037\032\035/config/v1/user-config/{name}'
  _USERCONFIG.methods_by_name['set']._options = None
  _USERCONFIG.methods_by_name['set']._serialized_options = b'\202\323\344\223\002\037\"\035/config/v1/user-config/{name}'
  _USERCONFIG.methods_by_name['delete']._options = None
  _USERCONFIG.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002\037*\035/config/v1/user-config/{name}'
  _USERCONFIG.methods_by_name['get']._options = None
  _USERCONFIG.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\037\022\035/config/v1/user-config/{name}'
  _USERCONFIG.methods_by_name['list']._options = None
  _USERCONFIG.methods_by_name['list']._serialized_options = b'\202\323\344\223\002;\022\027/config/v1/user-configsZ \"\036/config/v1/user-configs/search'
  _USERCONFIG.methods_by_name['stat']._options = None
  _USERCONFIG.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\036\"\034/config/v1/user-configs/stat'
  _SETUSERCONFIGREQUEST._serialized_start=192
  _SETUSERCONFIGREQUEST._serialized_end=325
  _USERCONFIGREQUEST._serialized_start=327
  _USERCONFIGREQUEST._serialized_end=379
  _GETUSERCONFIGREQUEST._serialized_start=381
  _GETUSERCONFIGREQUEST._serialized_end=450
  _USERCONFIGQUERY._serialized_start=452
  _USERCONFIGQUERY._serialized_end=563
  _USERCONFIGINFO._serialized_start=566
  _USERCONFIGINFO._serialized_end=750
  _USERCONFIGSINFO._serialized_start=752
  _USERCONFIGSINFO._serialized_end=847
  _USERCONFIGSTATQUERY._serialized_start=849
  _USERCONFIGSTATQUERY._serialized_end=943
  _USERCONFIG._serialized_start=946
  _USERCONFIG._serialized_end=1879
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/identity/v1/domain_owner.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+spaceone/api/identity/v1/domain_owner.proto\x12\x18spaceone.api.identity.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\"\x8b\x01\n\x11\x43reateDomainOwner\x12\x10\n\x08owner_id\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x10\n\x08language\x18\x07 \x01(\t\x12\x10\n\x08timezone\x18\x08 \x01(\t\x12\x11\n\tdomain_id\x18\n \x01(\t\"\x8b\x01\n\x11UpdateDomainOwner\x12\x10\n\x08owner_id\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x10\n\x08language\x18\x07 \x01(\t\x12\x10\n\x08timezone\x18\x08 \x01(\t\x12\x11\n\tdomain_id\x18\n \x01(\t\"9\n\x12\x44omainOwnerRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x10\n\x08owner_id\x18\x02 \x01(\t\"J\n\x15GetDomainOwnerRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x10\n\x08owner_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xa5\x01\n\x0f\x44omainOwnerInfo\x12\x10\n\x08owner_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\x12\x10\n\x08language\x18\x07 \x01(\t\x12\x10\n\x08timezone\x18\x08 \x01(\t\x12\x18\n\x10last_accessed_at\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x0c \x01(\t\x12\x11\n\tdomain_id\x18\r \x01(\t2\xc4\x04\n\x0b\x44omainOwner\x12\x8f\x01\n\x06\x63reate\x12+.spaceone.api.identity.v1.CreateDomainOwner\x1a).spaceone.api.identity.v1.DomainOwnerInfo\"-\x82\xd3\xe4\x93\x02\'\"%/identity/v1/domain/{domain_id}/owner\x12\x90\x01\n\x06update\x12+.spaceone.api.identity.v1.UpdateDomainOwner\x1a).spaceone.api.identity.v1.DomainOwnerInfo\".\x82\xd3\xe4\x93\x02(\x1a& /identity/v1/domain/{domain_id}/owner\x12}\n\x06\x64\x65lete\x12,.spaceone.api.identity.v1.DomainOwnerRequest\x1a\x16.google.protobuf.Empty\"-\x82\xd3\xe4\x93\x02\'*%/identity/v1/domain/{domain_id}/owner\x12\x90\x01\n\x03get\x12/.spaceone.api.identity.v1.GetDomainOwnerRequest\x1a).spaceone.api.identity.v1.DomainOwnerInfo\"-\x82\xd3\xe4\x93\x02\'\x12%/identity/v1/domain/{domain_id}/ownerb\x06proto3')



_CREATEDOMAINOWNER = DESCRIPTOR.message_types_by_name['CreateDomainOwner']
_UPDATEDOMAINOWNER = DESCRIPTOR.message_types_by_name['UpdateDomainOwner']
_DOMAINOWNERREQUEST = DESCRIPTOR.message_types_by_name['DomainOwnerRequest']
_GETDOMAINOWNERREQUEST = DESCRIPTOR.message_types_by_name['GetDomainOwnerRequest']
_DOMAINOWNERINFO = DESCRIPTOR.message_types_by_name['DomainOwnerInfo']
CreateDomainOwner = _reflection.GeneratedProtocolMessageType('CreateDomainOwner', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDOMAINOWNER,
  '__module__' : 'spaceone.api.identity.v1.domain_owner_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.CreateDomainOwner)
  })
_sym_db.RegisterMessage(CreateDomainOwner)

UpdateDomainOwner = _reflection.GeneratedProtocolMessageType('UpdateDomainOwner', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDOMAINOWNER,
  '__module__' : 'spaceone.api.identity.v1.domain_owner_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.UpdateDomainOwner)
  })
_sym_db.RegisterMessage(UpdateDomainOwner)

DomainOwnerRequest = _reflection.GeneratedProtocolMessageType('DomainOwnerRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINOWNERREQUEST,
  '__module__' : 'spaceone.api.identity.v1.domain_owner_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.DomainOwnerRequest)
  })
_sym_db.RegisterMessage(DomainOwnerRequest)

GetDomainOwnerRequest = _reflection.GeneratedProtocolMessageType('GetDomainOwnerRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDOMAINOWNERREQUEST,
  '__module__' : 'spaceone.api.identity.v1.domain_owner_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.GetDomainOwnerRequest)
  })
_sym_db.RegisterMessage(GetDomainOwnerRequest)

DomainOwnerInfo = _reflection.GeneratedProtocolMessageType('DomainOwnerInfo', (_message.Message,), {
  'DESCRIPTOR' : _DOMAINOWNERINFO,
  '__module__' : 'spaceone.api.identity.v1.domain_owner_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.DomainOwnerInfo)
  })
_sym_db.RegisterMessage(DomainOwnerInfo)

_DOMAINOWNER = DESCRIPTOR.services_by_name['DomainOwner']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DOMAINOWNER.methods_by_name['create']._options = None
  _DOMAINOWNER.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\'\"%/identity/v1/domain/{domain_id}/owner'
  _DOMAINOWNER.methods_by_name['update']._options = None
  _DOMAINOWNER.methods_by_name['update']._serialized_options = b'\202\323\344\223\002(\032& /identity/v1/domain/{domain_id}/owner'
  _DOMAINOWNER.methods_by_name['delete']._options = None
  _DOMAINOWNER.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002\'*%/identity/v1/domain/{domain_id}/owner'
  _DOMAINOWNER.methods_by_name['get']._options = None
  _DOMAINOWNER.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\'\022%/identity/v1/domain/{domain_id}/owner'
  _CREATEDOMAINOWNER._serialized_start=133
  _CREATEDOMAINOWNER._serialized_end=272
  _UPDATEDOMAINOWNER._serialized_start=275
  _UPDATEDOMAINOWNER._serialized_end=414
  _DOMAINOWNERREQUEST._serialized_start=416
  _DOMAINOWNERREQUEST._serialized_end=473
  _GETDOMAINOWNERREQUEST._serialized_start=475
  _GETDOMAINOWNERREQUEST._serialized_end=549
  _DOMAINOWNERINFO._serialized_start=552
  _DOMAINOWNERINFO._serialized_end=717
  _DOMAINOWNER._serialized_start=720
  _DOMAINOWNER._serialized_end=1300
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/metric.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&spaceone/api/inventory/v1/metric.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"F\n\x10GetMetricRequest\x12\x11\n\tmetric_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xac\x01\n\x0bMetricQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tmetric_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\x12\x10\n\x08provider\x18\x06 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x07 \x01(\t\x12\x13\n\x0bresource_id\x18\x08 \x01(\t\x12\x13\n\x0bmetric_name\x18\t \x01(\t\"\xa1\x02\n\nMetricInfo\x12\x11\n\tmetric_id\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\x12\x13\n\x0bresource_id\x18\x05 \x01(\t\x12*\n\tmeta_data\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04\x64\x61ta\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\ttimestamp\x18\x08 \x01(\t\x12\x13\n\x0bmetric_name\x18\t \x01(\t\x12\x12\n\nupdated_at\x18\n \x01(\t\x12\x12\n\ncreated_at\x18\x0b \x01(\t\x12\x12\n\ndeleted_at\x18\x0c \x01(\t\"Z\n\x0bMetricsInfo\x12\x36\n\x07results\x18\x01 \x03(\x0b\x32%.spaceone.api.inventory.v1.MetricInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"Z\n\x0fMetricStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\x92\x04\n\x06Metric\x12\x95\x01\n\x04list\x12&.spaceone.api.inventory.v1.MetricQuery\x1a&.spaceone.api.inventory.v1.MetricsInfo\"=\x82\xd3\xe4\x93\x02\x37\x12\x15/inventory/v1/metricsZ\x1e\"\x1c/inventory/v1/metrics/search\x12o\n\x04stat\x12*.spaceone.api.inventory.v1.MetricStatQuery\x1a\x17.google.protobuf.Struct\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/inventory/v1/metrics/stat\x12\x83\x01\n\x03get\x12+.spaceone.api.inventory.v1.GetMetricRequest\x1a%.spaceone.api.inventory.v1.MetricInfo\"(\x82\xd3\xe4\x93\x02\"\" /inventory/v1/metric/{metric_id}\x12y\n\tstat_diff\x12*.spaceone.api.inventory.v1.MetricStatQuery\x1a\x17.google.protobuf.Struct\"\'\x82\xd3\xe4\x93\x02!\"\x1f/inventory/v1/metrics/stat_diffb\x06proto3')



_GETMETRICREQUEST = DESCRIPTOR.message_types_by_name['GetMetricRequest']
_METRICQUERY = DESCRIPTOR.message_types_by_name['MetricQuery']
_METRICINFO = DESCRIPTOR.message_types_by_name['MetricInfo']
_METRICSINFO = DESCRIPTOR.message_types_by_name['MetricsInfo']
_METRICSTATQUERY = DESCRIPTOR.message_types_by_name['MetricStatQuery']
GetMetricRequest = _reflection.GeneratedProtocolMessageType('GetMetricRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMETRICREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetMetricRequest)
  })
_sym_db.RegisterMessage(GetMetricRequest)

MetricQuery = _reflection.GeneratedProtocolMessageType('MetricQuery', (_message.Message,), {
  'DESCRIPTOR' : _METRICQUERY,
  '__module__' : 'spaceone.api.inventory.v1.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.MetricQuery)
  })
_sym_db.RegisterMessage(MetricQuery)

MetricInfo = _reflection.GeneratedProtocolMessageType('MetricInfo', (_message.Message,), {
  'DESCRIPTOR' : _METRICINFO,
  '__module__' : 'spaceone.api.inventory.v1.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.MetricInfo)
  })
_sym_db.RegisterMessage(MetricInfo)

MetricsInfo = _reflection.GeneratedProtocolMessageType('MetricsInfo', (_message.Message,), {
  'DESCRIPTOR' : _METRICSINFO,
  '__module__' : 'spaceone.api.inventory.v1.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.MetricsInfo)
  })
_sym_db.RegisterMessage(MetricsInfo)

MetricStatQuery = _reflection.GeneratedProtocolMessageType('MetricStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _METRICSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.MetricStatQuery)
  })
_sym_db.RegisterMessage(MetricStatQuery)

_METRIC = DESCRIPTOR.services_by_name['Metric']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _METRIC.methods_by_name['list']._options = None
  _METRIC.methods_by_name['list']._serialized_options = b'\202\323\344\223\0027\022\025/inventory/v1/metricsZ\036\"\034/inventory/v1/metrics/search'
  _METRIC.methods_by_name['stat']._options = None
  _METRIC.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\034\"\032/inventory/v1/metrics/stat'
  _METRIC.methods_by_name['get']._options = None
  _METRIC.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\"\" /inventory/v1/metric/{metric_id}'
  _METRIC.methods_by_name['stat_diff']._options = None
  _METRIC.methods_by_name['stat_diff']._serialized_options = b'\202\323\344\223\002!\"\037/inventory/v1/metrics/stat_diff'
  _GETMETRICREQUEST._serialized_start=192
  _GETMETRICREQUEST._serialized_end=262
  _METRICQUERY._serialized_start=265
  _METRICQUERY._serialized_end=437
  _METRICINFO._serialized_start=440
  _METRICINFO._serialized_end=729
  _METRICSINFO._serialized_start=731
  _METRICSINFO._serialized_end=821
  _METRICSTATQUERY._serialized_start=823
  _METRICSTATQUERY._serialized_end=913
  _METRIC._serialized_start=916
  _METRIC._serialized_end=1446
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.board.v1 import post_pb2 as spaceone_dot_api_dot_board_dot_v1_dot_post__pb2


class PostStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.board.v1.Post/create',
                request_serializer=spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.CreatePostRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.PostInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.board.v1.Post/update',
                request_serializer=spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.UpdatePostRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.PostInfo.FromString,
                )
        self.send_notification = channel.unary_unary(
                '/spaceone.api.board.v1.Post/send_notification',
                request_serializer=spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.SendNotificationRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.board.v1.Post/delete',
                request_serializer=spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.PostRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.board.v1.Post/get',
                request_serializer=spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.GetPostRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.PostInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.board.v1.Post/list',
                request_serializer=spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.PostQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.PostsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.board.v1.Post/stat',
                request_serializer=spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.PostStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class PostServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new Post under a specific Board. You must specify the `board_id`, `title`, and `contents`. The parameter `category` is not required but can be set in the scope of `categories` specified in the parent Board. You can make the new Post pinned or pop up by adjusting the parameters.
        request_example: >-
        {
        "board_id": "board-123456789012",
        "category": "developer",
        "title": "title",
        "contents": "This is contents.",
        "options": {"is_popup": true},
        "writer": "user1",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "board_id": "board-123456789012",
        "post_id": "post-123456789012",
        "post_type": "INTERNAL",
        "category": "developer",
        "title": "title",
        "contents": "This is contents.",
        "options": {
        "is_pinned": false,
        "is_popup": true
        },
        "view_count": 0,
        "writer": "user1",
        "scope": "DOMAIN",
        "domain_id": "domain-123456789012",
        "user_id": "user1@email.com",
        "created_at": "2022-01-01T01:06:23.732Z",
        "updated_at": "2022-01-01T01:06:23.732Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific Post. You can make changes in Post settings, except `board_id`, `post_id`, and `domain_id`.
        request_example: >-
        {
        "board_id": "board-123456789012",
        "post_id": "post-2118473ce15e",
        "category": "developer",
        "title": "title2",
        "contents": "this is contents2.",
        "options": {
        "is_popup": false,
        "is_pinned": true
        },
        "writer": "user1",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "board_id": "board-123456789012",
        "post_id": "post-123456789012",
        "post_type": "INTERNAL",
        "category": "developer",
        "title": "title2",
        "contents": "this is contents2.",
        "options": {
        "is_popup": false,
        "is_pinned": true
        },
        "view_count": 1,
        "writer": "user1",
        "scope": "DOMAIN",
        "domain_id": "domain-123456789012",
        "user_id": "user1@email.com",
        "created_at": "2022-06-13T01:06:23.732Z",
        "updated_at": "2022-06-13T01:06:23.732Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def send_notification(self, request, context):
        """
        desc: Not Implemented
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific Post. You must specify the `post_id` of the Post to delete, and the `board_id` of the Board where the child Post to delete belongs.
        request_example: >-
        {
        "board_id": "board-b9aa34e65c60",
        "post_id": "post-2118473ce15e",
        "domain_id": "domain-123456789012"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific Post. You must specify the `post_id` of the Post to get, and the `board_id` of the Board where the child Post to get belongs. Prints detailed information about the Post.
        request_example: >-
        {
        "board_id": "board-b9aa34e65c60",
        "post_id": "post-2118473ce15e",
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "board_id": "board-b9aa34e65c60",
        "post_id": "post-2118473ce15e",
        "post_type": "INTERNAL",
        "category": "flower",
        "title": "title",
        "contents": "this is contents.",
        "options": {
        "is_pinned": false,
        "is_popup": true
        },
        "view_count": 2,
        "writer": "seolmin",
        "scope": "DOMAIN",
        "domain_id": "domain-58010aa2e451",
        "user_id": "supervisor",
        "created_at": "2022-06-13T01:06:23.732Z",
        "updated_at": "2022-06-13T01:06:23.732Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all Posts. You can use a query to get a filtered list of Posts.
        request_example: >-
        {
        "board_id": "board-b9aa34e65c60",
        "query": {}
        }
        response_example: >-
        {
        "results": [
        {
        "board_id": "board-b9aa34e65c60",
        "post_id": "post-2118473ce15e",
        "post_type": "INTERNAL",
        "category": "spaceone",
        "title": "title2",
        "contents": "this is contents2.",
        "options": {
        "is_popup": false,
        "is_pinned": true
        },
        "view_count": 3,
        "writer": "seolmin2",
        "scope": "DOMAIN",
        "domain_id": "domain-58010aa2e451",
        "user_id": "user1@email.com",
        "created_at": "2022-06-13T01:06:23.732Z",
        "updated_at": "2022-06-13T01:06:23.732Z"
        },
        {
        "board_id": "board-b9aa34e65c60",
        "post_id": "post-532ae1191233",
        "post_type": "INTERNAL",
        "category": "flower",
        "title": "작업공지",
        "contents": "This is description",
        "options": {
        "is_pinned": true,
        "is_popup": true
        },
        "writer": "권설민",
        "scope": "PUBLIC",
        "user_id": "supervisor",
        "created_at": "2022-06-10T07:01:44.384Z",
        "updated_at": "2022-06-10T07:01:44.384Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PostServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.CreatePostRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.PostInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.UpdatePostRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.PostInfo.SerializeToString,
            ),
            'send_notification': grpc.unary_unary_rpc_method_handler(
                    servicer.send_notification,
                    request_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.SendNotificationRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.PostRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.GetPostRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.PostInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.PostQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.PostsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.PostStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.board.v1.Post', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Post(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.board.v1.Post/create',
            spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.CreatePostRequest.SerializeToString,
            spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.PostInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.board.v1.Post/update',
            spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.UpdatePostRequest.SerializeToString,
            spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.PostInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def send_notification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.board.v1.Post/send_notification',
            spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.SendNotificationRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.board.v1.Post/delete',
            spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.PostRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.board.v1.Post/get',
            spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.GetPostRequest.SerializeToString,
            spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.PostInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.board.v1.Post/list',
            spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.PostQuery.SerializeToString,
            spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.PostsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.board.v1.Post/stat',
            spaceone_dot_api_dot_board_dot_v1_dot_post__pb2.PostStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/notification/v1/user_channel.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/spaceone/api/notification/v1/user_channel.proto\x12\x1cspaceone.api.notification.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xe3\x01\n\x13UserChannelSchedule\x12P\n\x0b\x64\x61y_of_week\x18\x01 \x03(\x0e\x32;.spaceone.api.notification.v1.UserChannelSchedule.DayOfWeek\x12\x12\n\nstart_hour\x18\x02 \x01(\x05\x12\x10\n\x08\x65nd_hour\x18\x03 \x01(\x05\"T\n\tDayOfWeek\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03MON\x10\x01\x12\x07\n\x03TUE\x10\x02\x12\x07\n\x03WED\x10\x03\x12\x07\n\x03THU\x10\x04\x12\x07\n\x03\x46RI\x10\x05\x12\x07\n\x03SAT\x10\x06\x12\x07\n\x03SUN\x10\x07\"\xb7\x02\n\x18\x43reateUserChannelRequest\x12\x13\n\x0bprotocol_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x14\n\x0cis_subscribe\x18\x04 \x01(\x08\x12\x15\n\rsubscriptions\x18\x05 \x03(\t\x12\x14\n\x0cis_scheduled\x18\x06 \x01(\x08\x12\x43\n\x08schedule\x18\x07 \x01(\x0b\x32\x31.spaceone.api.notification.v1.UserChannelSchedule\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07user_id\x18\x15 \x01(\t\x12\x11\n\tdomain_id\x18\x16 \x01(\t\"\xe7\x01\n\x18UpdateUserChannelRequest\x12\x17\n\x0fuser_channel_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x43\n\x08schedule\x18\x04 \x01(\x0b\x32\x31.spaceone.api.notification.v1.UserChannelSchedule\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xa9\x01\n UpdateUserChannelScheduleRequest\x12\x17\n\x0fuser_channel_id\x18\x01 \x01(\t\x12\x14\n\x0cis_scheduled\x18\x02 \x01(\x08\x12\x43\n\x08schedule\x18\x03 \x01(\x0b\x32\x31.spaceone.api.notification.v1.UserChannelSchedule\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"\x7f\n$UpdateUserChannelSubscriptionRequest\x12\x17\n\x0fuser_channel_id\x18\x01 \x01(\t\x12\x14\n\x0cis_subscribe\x18\x02 \x01(\x08\x12\x15\n\rsubscriptions\x18\x03 \x03(\t\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"@\n\x12UserChannelRequest\x12\x17\n\x0fuser_channel_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"Q\n\x15GetUserChannelRequest\x12\x17\n\x0fuser_channel_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xba\x02\n\x10UserChannelQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x17\n\x0fuser_channel_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12N\n\x05state\x18\x04 \x01(\x0e\x32?.spaceone.api.notification.v1.UserChannelQuery.UserChannelState\x12\x11\n\tsecret_id\x18\x05 \x01(\t\x12\x13\n\x0bprotocol_id\x18\x0b \x01(\t\x12\x0f\n\x07user_id\x18\x0c \x01(\t\x12\x11\n\tdomain_id\x18\r \x01(\t\"7\n\x10UserChannelState\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"\xf6\x03\n\x0fUserChannelInfo\x12\x17\n\x0fuser_channel_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12M\n\x05state\x18\x03 \x01(\x0e\x32>.spaceone.api.notification.v1.UserChannelInfo.UserChannelState\x12%\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tsecret_id\x18\x05 \x01(\t\x12\x14\n\x0cis_subscribe\x18\x06 \x01(\x08\x12\x15\n\rsubscriptions\x18\x07 \x03(\t\x12\x14\n\x0cis_scheduled\x18\x08 \x01(\x08\x12\x43\n\x08schedule\x18\t \x01(\x0b\x32\x31.spaceone.api.notification.v1.UserChannelSchedule\x12%\n\x04tags\x18\n \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0bprotocol_id\x18\x0b \x01(\t\x12\x0f\n\x07user_id\x18\x0c \x01(\t\x12\x11\n\tdomain_id\x18\r \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\"7\n\x10UserChannelState\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"g\n\x10UserChannelsInfo\x12>\n\x07results\x18\x01 \x03(\x0b\x32-.spaceone.api.notification.v1.UserChannelInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"_\n\x14UserChannelStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xac\r\n\x0bUserChannel\x12\x97\x01\n\x06\x63reate\x12\x36.spaceone.api.notification.v1.CreateUserChannelRequest\x1a-.spaceone.api.notification.v1.UserChannelInfo\"&\x82\xd3\xe4\x93\x02 \"\x1e/notification/v1/user-channels\x12\xa8\x01\n\x06update\x12\x36.spaceone.api.notification.v1.UpdateUserChannelRequest\x1a-.spaceone.api.notification.v1.UserChannelInfo\"7\x82\xd3\xe4\x93\x02\x31\x1a//notification/v1/user-channel/{user_channel_id}\x12\xbf\x01\n\x0cset_schedule\x12>.spaceone.api.notification.v1.UpdateUserChannelScheduleRequest\x1a-.spaceone.api.notification.v1.UserChannelInfo\"@\x82\xd3\xe4\x93\x02:\x1a\x38/notification/v1/user-channel/{user_channel_id}/schedule\x12\xcb\x01\n\x10set_subscription\x12\x42.spaceone.api.notification.v1.UpdateUserChannelSubscriptionRequest\x1a-.spaceone.api.notification.v1.UserChannelInfo\"D\x82\xd3\xe4\x93\x02>\x1a</notification/v1/user-channel/{user_channel_id}/subscription\x12\xa9\x01\n\x06\x65nable\x12\x30.spaceone.api.notification.v1.UserChannelRequest\x1a-.spaceone.api.notification.v1.UserChannelInfo\">\x82\xd3\xe4\x93\x02\x38\x1a\x36/notification/v1/user-channel/{user_channel_id}/enable\x12\xab\x01\n\x07\x64isable\x12\x30.spaceone.api.notification.v1.UserChannelRequest\x1a-.spaceone.api.notification.v1.UserChannelInfo\"?\x82\xd3\xe4\x93\x02\x39\x1a\x37/notification/v1/user-channel/{user_channel_id}/disable\x12\x8b\x01\n\x06\x64\x65lete\x12\x30.spaceone.api.notification.v1.UserChannelRequest\x1a\x16.google.protobuf.Empty\"7\x82\xd3\xe4\x93\x02\x31*//notification/v1/user-channel/{user_channel_id}\x12\xa2\x01\n\x03get\x12\x33.spaceone.api.notification.v1.GetUserChannelRequest\x1a-.spaceone.api.notification.v1.UserChannelInfo\"7\x82\xd3\xe4\x93\x02\x31\x12//notification/v1/user-channel/{user_channel_id}\x12\xb7\x01\n\x04list\x12..spaceone.api.notification.v1.UserChannelQuery\x1a..spaceone.api.notification.v1.UserChannelsInfo\"O\x82\xd3\xe4\x93\x02I\x12\x1e/notification/v1/user-channelsZ\'\"%/notification/v1/user-channels/search\x12\x80\x01\n\x04stat\x12\x32.spaceone.api.notification.v1.UserChannelStatQuery\x1a\x17.google.protobuf.Struct\"+\x82\xd3\xe4\x93\x02%\"#/notification/v1/user-channels/statb\x06proto3')



_USERCHANNELSCHEDULE = DESCRIPTOR.message_types_by_name['UserChannelSchedule']
_CREATEUSERCHANNELREQUEST = DESCRIPTOR.message_types_by_name['CreateUserChannelRequest']
_UPDATEUSERCHANNELREQUEST = DESCRIPTOR.message_types_by_name['UpdateUserChannelRequest']
_UPDATEUSERCHANNELSCHEDULEREQUEST = DESCRIPTOR.message_types_by_name['UpdateUserChannelScheduleRequest']
_UPDATEUSERCHANNELSUBSCRIPTIONREQUEST = DESCRIPTOR.message_types_by_name['UpdateUserChannelSubscriptionRequest']
_USERCHANNELREQUEST = DESCRIPTOR.message_types_by_name['UserChannelRequest']
_GETUSERCHANNELREQUEST = DESCRIPTOR.message_types_by_name['GetUserChannelRequest']
_USERCHANNELQUERY = DESCRIPTOR.message_types_by_name['UserChannelQuery']
_USERCHANNELINFO = DESCRIPTOR.message_types_by_name['UserChannelInfo']
_USERCHANNELSINFO = DESCRIPTOR.message_types_by_name['UserChannelsInfo']
_USERCHANNELSTATQUERY = DESCRIPTOR.message_types_by_name['UserChannelStatQuery']
_USERCHANNELSCHEDULE_DAYOFWEEK = _USERCHANNELSCHEDULE.enum_types_by_name['DayOfWeek']
_USERCHANNELQUERY_USERCHANNELSTATE = _USERCHANNELQUERY.enum_types_by_name['UserChannelState']
_USERCHANNELINFO_USERCHANNELSTATE = _USERCHANNELINFO.enum_types_by_name['UserChannelState']
UserChannelSchedule = _reflection.GeneratedProtocolMessageType('UserChannelSchedule', (_message.Message,), {
  'DESCRIPTOR' : _USERCHANNELSCHEDULE,
  '__module__' : 'spaceone.api.notification.v1.user_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.UserChannelSchedule)
  })
_sym_db.RegisterMessage(UserChannelSchedule)

CreateUserChannelRequest = _reflection.GeneratedProtocolMessageType('CreateUserChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEUSERCHANNELREQUEST,
  '__module__' : 'spaceone.api.notification.v1.user_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.CreateUserChannelRequest)
  })
_sym_db.RegisterMessage(CreateUserChannelRequest)

UpdateUserChannelRequest = _reflection.GeneratedProtocolMessageType('UpdateUserChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERCHANNELREQUEST,
  '__module__' : 'spaceone.api.notification.v1.user_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.UpdateUserChannelRequest)
  })
_sym_db.RegisterMessage(UpdateUserChannelRequest)

UpdateUserChannelScheduleRequest = _reflection.GeneratedProtocolMessageType('UpdateUserChannelScheduleRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERCHANNELSCHEDULEREQUEST,
  '__module__' : 'spaceone.api.notification.v1.user_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.UpdateUserChannelScheduleRequest)
  })
_sym_db.RegisterMessage(UpdateUserChannelScheduleRequest)

UpdateUserChannelSubscriptionRequest = _reflection.GeneratedProtocolMessageType('UpdateUserChannelSubscriptionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEUSERCHANNELSUBSCRIPTIONREQUEST,
  '__module__' : 'spaceone.api.notification.v1.user_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.UpdateUserChannelSubscriptionRequest)
  })
_sym_db.RegisterMessage(UpdateUserChannelSubscriptionRequest)

UserChannelRequest = _reflection.GeneratedProtocolMessageType('UserChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _USERCHANNELREQUEST,
  '__module__' : 'spaceone.api.notification.v1.user_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.UserChannelRequest)
  })
_sym_db.RegisterMessage(UserChannelRequest)

GetUserChannelRequest = _reflection.GeneratedProtocolMessageType('GetUserChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETUSERCHANNELREQUEST,
  '__module__' : 'spaceone.api.notification.v1.user_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.GetUserChannelRequest)
  })
_sym_db.RegisterMessage(GetUserChannelRequest)

UserChannelQuery = _reflection.GeneratedProtocolMessageType('UserChannelQuery', (_message.Message,), {
  'DESCRIPTOR' : _USERCHANNELQUERY,
  '__module__' : 'spaceone.api.notification.v1.user_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.UserChannelQuery)
  })
_sym_db.RegisterMessage(UserChannelQuery)

UserChannelInfo = _reflection.GeneratedProtocolMessageType('UserChannelInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERCHANNELINFO,
  '__module__' : 'spaceone.api.notification.v1.user_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.UserChannelInfo)
  })
_sym_db.RegisterMessage(UserChannelInfo)

UserChannelsInfo = _reflection.GeneratedProtocolMessageType('UserChannelsInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERCHANNELSINFO,
  '__module__' : 'spaceone.api.notification.v1.user_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.UserChannelsInfo)
  })
_sym_db.RegisterMessage(UserChannelsInfo)

UserChannelStatQuery = _reflection.GeneratedProtocolMessageType('UserChannelStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _USERCHANNELSTATQUERY,
  '__module__' : 'spaceone.api.notification.v1.user_channel_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.UserChannelStatQuery)
  })
_sym_db.RegisterMessage(UserChannelStatQuery)

_USERCHANNEL = DESCRIPTOR.services_by_name['UserChannel']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _USERCHANNEL.methods_by_name['create']._options = None
  _USERCHANNEL.methods_by_name['create']._serialized_options = b'\202\323\344\223\002 \"\036/notification/v1/user-channels'
  _USERCHANNEL.methods_by_name['update']._options = None
  _USERCHANNEL.methods_by_name['update']._serialized_options = b'\202\323\344\223\0021\032//notification/v1/user-channel/{user_channel_id}'
  _USERCHANNEL.methods_by_name['set_schedule']._options = None
  _USERCHANNEL.methods_by_name['set_schedule']._serialized_options = b'\202\323\344\223\002:\0328/notification/v1/user-channel/{user_channel_id}/schedule'
  _USERCHANNEL.methods_by_name['set_subscription']._options = None
  _USERCHANNEL.methods_by_name['set_subscription']._serialized_options = b'\202\323\344\223\002>\032</notification/v1/user-channel/{user_channel_id}/subscription'
  _USERCHANNEL.methods_by_name['enable']._options = None
  _USERCHANNEL.methods_by_name['enable']._serialized_options = b'\202\323\344\223\0028\0326/notification/v1/user-channel/{user_channel_id}/enable'
  _USERCHANNEL.methods_by_name['disable']._options = None
  _USERCHANNEL.methods_by_name['disable']._serialized_options = b'\202\323\344\223\0029\0327/notification/v1/user-channel/{user_channel_id}/disable'
  _USERCHANNEL.methods_by_name['delete']._options = None
  _USERCHANNEL.methods_by_name['delete']._serialized_options = b'\202\323\344\223\0021*//notification/v1/user-channel/{user_channel_id}'
  _USERCHANNEL.methods_by_name['get']._options = None
  _USERCHANNEL.methods_by_name['get']._serialized_options = b'\202\323\344\223\0021\022//notification/v1/user-channel/{user_channel_id}'
  _USERCHANNEL.methods_by_name['list']._options = None
  _USERCHANNEL.methods_by_name['list']._serialized_options = b'\202\323\344\223\002I\022\036/notification/v1/user-channelsZ\'\"%/notification/v1/user-channels/search'
  _USERCHANNEL.methods_by_name['stat']._options = None
  _USERCHANNEL.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002%\"#/notification/v1/user-channels/stat'
  _USERCHANNELSCHEDULE._serialized_start=205
  _USERCHANNELSCHEDULE._serialized_end=432
  _USERCHANNELSCHEDULE_DAYOFWEEK._serialized_start=348
  _USERCHANNELSCHEDULE_DAYOFWEEK._serialized_end=432
  _CREATEUSERCHANNELREQUEST._serialized_start=435
  _CREATEUSERCHANNELREQUEST._serialized_end=746
  _UPDATEUSERCHANNELREQUEST._serialized_start=749
  _UPDATEUSERCHANNELREQUEST._serialized_end=980
  _UPDATEUSERCHANNELSCHEDULEREQUEST._serialized_start=983
  _UPDATEUSERCHANNELSCHEDULEREQUEST._serialized_end=1152
  _UPDATEUSERCHANNELSUBSCRIPTIONREQUEST._serialized_start=1154
  _UPDATEUSERCHANNELSUBSCRIPTIONREQUEST._serialized_end=1281
  _USERCHANNELREQUEST._serialized_start=1283
  _USERCHANNELREQUEST._serialized_end=1347
  _GETUSERCHANNELREQUEST._serialized_start=1349
  _GETUSERCHANNELREQUEST._serialized_end=1430
  _USERCHANNELQUERY._serialized_start=1433
  _USERCHANNELQUERY._serialized_end=1747
  _USERCHANNELQUERY_USERCHANNELSTATE._serialized_start=1692
  _USERCHANNELQUERY_USERCHANNELSTATE._serialized_end=1747
  _USERCHANNELINFO._serialized_start=1750
  _USERCHANNELINFO._serialized_end=2252
  _USERCHANNELINFO_USERCHANNELSTATE._serialized_start=1692
  _USERCHANNELINFO_USERCHANNELSTATE._serialized_end=1747
  _USERCHANNELSINFO._serialized_start=2254
  _USERCHANNELSINFO._serialized_end=2357
  _USERCHANNELSTATQUERY._serialized_start=2359
  _USERCHANNELSTATQUERY._serialized_end=2454
  _USERCHANNEL._serialized_start=2457
  _USERCHANNEL._serialized_end=4165
# @@protoc_insertion_point(module_scope)
